<?xml version="1.0" ?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp "&#160;"> ]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="html" encoding="utf-8"/>

<!-- This generates the HTML page, it's mostly just HTML tags. Templates to translate tscript.xml are near the end. -->
<xsl:template match="/tscript">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"/>
<meta http-equiv="Content-Style-Type" content="text/css"/>
<title>Trespasser Script Reference</title>
<style type="text/css">
&lt;!--
a:link    {text-decoration:underline; color:#0000FF; }
a:hover   {text-decoration:underline; color:#0000FF; }
a:visited {text-decoration:underline; color:#0000FF; }
.valuetype { color : #0000FF; }
.valuename { color : #BF4020; }
.special-note { color : #800000; }
th { font-weight : bold; }
--&gt;
</style>
</head>
<body bgcolor="#E8E8E8">

  <p align="center"><small>This page was automatically generated from <a href="tscript.xml">XML</a></small></p>
  <h1>Trespasser Script Reference</h1>
  
  <p>This document describes the classes and values of the scripting used by Trespasser. The syntax of the script is
  that used by <a href="http://www.geocities.com/andres_james/TresView/">TresEd</a>, the Trespasser Level Editor.
  </p>

  <p>
    <b>Script Reference:</b><br/>
    <a href="#Classes">General Script Classes</a><br/>
    <a href="#Triggers">Trigger Classes</a><br/>
    <a href="#Actions">Trigger Actions</a><br/>
  </p>
  <b>Notes:</b>
  <ul>
  <li>Default value "none" means value is optional and only used if specified.</li>
  <li>A '$' object is one whose name begins with '$' and is used by the physics engine.</li>
  <li>If restrictions (eg. "Named object must exist") are not honored, Trespasser may behave oddly or crash.</li>
  <li>If a value is listed as "Must specify", Trespasser may behave oddly or crash if the value is not specified.</li>
  </ul>
  <p><b>Disclaimer:</b> This page is work in progress, is far from complete, and has not been thoroughly checked so use it just as a guide.</p>
  
  <hr/>
  <h2 align="center"><a name="Classes">General Script Classes and Values</a></h2>
  
  <p>Values are case sensitive and strongly typed. This means that if you type "moveable" instead of "Moveable" or "int Frame" instead of "float Frame", Trespasser will ignore the value. Where the default value is listed as "must specify", Trespasser may behave badly or even crash if the value is not specified.</p>

  <p>The Class value determines the type of object, and all objects should specify it.</p>

  <table border="1" cellspacing="0" cellpadding="3">
    <tr>
        <td><strong>Type</strong></td>
        <td><strong>Name</strong></td>
        <td><strong>Default</strong></td>
        <td><strong>Description</strong></td>
    </tr>
    <tr>
        <td><span class="valuetype">string</span></td>
        <td><span class="valuename">Class</span></td>
        <td>&quot;CInstance&quot;</td>
        <td>Class of object, described below.</td>
    </tr>
</table>

  <p><b>Example:</b></p>
  <blockquote>
<pre>
group MyTerrainTexture = {
  string Class = &quot;CTerrainObj&quot;
  int Height = 1
  string SoundMaterial = &quot;Grass&quot;
}
</pre>
  </blockquote>

  <p><b>Classes:</b><br/>
  <xsl:for-each select="classes/class">
    <a href="#{@name}"><xsl:value-of select="@name"/></a><br/>
  </xsl:for-each>
  See also <a href="#Triggers">Trigger classes</a>
  </p>
  <p><span class="special-note">Possible classes, with unknown usage (not used in original levels): CHitSpang, CInput, CSocket, Default, Marker, TerrainExtent, CTest, CSubsystem.</span></p>

  <xsl:apply-templates select="classes/class"/>


  <br/><hr/>
  <h2 align="center"><a name="Triggers">Trigger Classes</a></h2>
  <p>Triggers perform one or more <a href="#Actions">actions</a> when certain conditions are met.
  The base class <a href="#CBooleanTrigger">CBooleanTrigger</a> evaluates a FireExpression monitoring the state of trigger instances.
  All other trigger classes inherit CBooleanTrigger's values, and have additional contitions to determine when the trigger fires.
  </p>
  <table border="0" cellpadding="5" cellspacing="0">
    <tr>
      <td align="center">
        <b>Class</b>
      </td>
      <td><b>What makes the trigger fire:</b></td>
    </tr>
    <tr>
      <td align="right">
        <p><a href="#CBooleanTrigger">CBooleanTrigger</a><br/>
        <a href="#CCollisionTrigger">CCollisionTrigger</a><br/>
        <a href="#CCreatureTrigger">CCreatureTrigger</a><br/>
        <a href="#CLocationTrigger">CLocationTrigger</a><br/>
        <a href="#CObjectTrigger">CObjectTrigger</a><br/>
        <a href="#CSequenceTrigger">CSequenceTrigger</a><br/>
        <a href="#CStartTrigger">CStartTrigger</a><br/>
        <a href="#CTimerTrigger">CTimerTrigger</a><br/>
        <a href="#CVariableTrigger">CVariableTrigger</a><br/>
        <font color="#800000">CMoreMassTrigger</font></p>
      </td>
      <td>When boolean expression of other triggers' states is true<br/>
        When objects collide<br/>
        When Anne or a dino dies<br/>
        When (Anne/object/dino) (enters/is in/exits) a location<br/>
        When an object is picked up, used, or dropped<br/>
        When a sequence of events occurs<br/>
        When the level starts<br/>
        At certain intervals<br/>
        Not really a trigger, just stores a boolean variable<br/>
        <font color="#800000">Usage unknown (not used in original levels)</font></td>
    </tr>
  </table>
  <!--<xsl:for-each select="triggers/class">
    <a href="#{@name}"><xsl:value-of select="@name"/></a><br/>
  </xsl:for-each>-->
  <p><b>Example:</b></p>
  <blockquote>
<pre>
group InsideHouseTigger = {
  string Class = "CLocationTrigger"
  bool PlayerEnterTrigger = true
  int ActionType = 34
  string OverlayText = "You have entered the house"
}
</pre>
  </blockquote>
  <xsl:apply-templates select="triggers/class"/>


  <br/><hr/>
  <h2 align="center"><a name="Actions">Trigger Actions</a></h2>
  <p>Actions that can happen when a <a href="#Triggers">trigger</a> fires.</p>
  <xsl:for-each select="actions/class">
    <a href="#{@actionType}={@name}">
      <xsl:value-of select="@actionType"/> = &quot;<xsl:value-of select="@name"/>&quot;
    </a><br/>
  </xsl:for-each>
  <p>The type of action is specified in the ActionType value of a trigger. If there is only one action for a trigger, the ActionType and the action's values can simply be added into the trigger group:</p>
<pre>
group SimpleActionTrigger = {
  string Class = "CStartTrigger"
  int ActionType = 34
  string OverlayText = "This trigger just displays some text."
}
</pre>
  <p>If there is more than one action, the actions are specified as ActionXX groups, each containing one ActionType, and that action's values. The trigger may also contain a ProcessStyle value to specify how the multiple actions are to be executed:</p>
<pre>
group MultipleActionTrigger = {
  string Class = "CStartTrigger"
  int ProcessStyle = 3
  group Action00 = {
    int ActionType = 0
    string Sample = "VA01"
  }
  group Action01 = {
    int ActionType = 25
    float Delay = 4.0
  }
  group Action02 = {
    int ActionType = 34
    string OverlayText = "This trigger plays a sound, waits 4 seconds,
                          then displays this text."
  }
}
</pre>
  <p>Some action types were not used in the original levels and their usage is unknown: 3, 4, 8, 12, 14, 15, 26, 30, 32, 33.</p>

  <xsl:apply-templates select="actions/class"/>
  
  <br/>
  <hr/>
  <p align="center">Page researched and created by <a href="mailto:tresutils@yahoo.com">Andres</a>, with additional research by Rebel.</p>
  <br/>
</body>
</html>
</xsl:template>


<xsl:template match="class">
  <xsl:choose>
    <xsl:when test="@actionType">
      <a name="#{@actionType}={@name}"><hr/></a>
        <h3>ActionType <xsl:value-of select="@actionType"/> = &quot;<xsl:value-of select="@name"/>&quot;</h3>
    </xsl:when>
    <xsl:otherwise>
      <a name="#{@name}"><hr/></a>
      <h3><xsl:value-of select="@name"/></h3>
    </xsl:otherwise>
  </xsl:choose>
  <p><xsl:apply-templates select="description"/></p>
  <xsl:if test="value">
    <table cellpadding="3" cellspacing="0" border="1">
      <tr>
        <th>Type</th>
        <th>Name</th>
        <th>Default</th>
        <th>Description</th>
      </tr>
      <xsl:apply-templates select="value|section"/>
    </table>
  </xsl:if>
  <xsl:apply-templates select="example"/>
  <p><span class="special-note"><xsl:apply-templates select="special-note"/></span></p>
</xsl:template>


<xsl:template match="class/section">
  <tr>
  <td colspan="4">
  <xsl:apply-templates/>
  </td>
  </tr>
</xsl:template>


<xsl:template match="value">
<xsl:if test="not(@doc-hide='true')">
  <tr>
  <td valign="top" class="valuetype"><xsl:value-of select="@type"/></td>
  <td valign="top" class="valuename">
    <xsl:choose>
      <xsl:when test="display-name"><xsl:apply-templates select="display-name"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise>
    </xsl:choose>
  </td>
  <td valign="top" nowrap="true"><xsl:choose>
    <xsl:when test="display-default"><xsl:value-of select="display-default"/></xsl:when>
    <xsl:when test="@default"><xsl:value-of select="@default"/></xsl:when>
    <xsl:when test="@required">must specify</xsl:when>
    <xsl:otherwise>unknown</xsl:otherwise>
    </xsl:choose></td>
  <td>
    <xsl:choose>
      <xsl:when test="string(description)"><xsl:apply-templates select="description"/></xsl:when>
      <xsl:otherwise>&nbsp;</xsl:otherwise>
    </xsl:choose>
    <xsl:if test="@check-object-ref"> (Named object must exist.)</xsl:if>
    <xsl:if test="@check-trigger-ref"> (Named trigger must exist.)</xsl:if>
    <xsl:if test="@check-physics-ref"> (Named '$' object must exist.)</xsl:if>
    <xsl:if test="@check-anim-ref"> (Named textures must exist.)</xsl:if>
    <xsl:for-each select="valid-value">
      <xsl:if test="not(@doc-hide)">
        <br/>
        <xsl:if test="../@type='string'">&quot;</xsl:if>
        <xsl:value-of select="@data"/>
        <xsl:if test="../@type='string'">&quot;</xsl:if>
        <xsl:choose>
          <xsl:when test="description"> = <xsl:apply-templates select="description"/></xsl:when>
          <xsl:when test="display-text"> = <xsl:apply-templates select="display-text"/></xsl:when>
        </xsl:choose>
      </xsl:if>
    </xsl:for-each>
  </td>
  </tr>
</xsl:if>
</xsl:template>


<xsl:template match="example">
  <p><b>Example:</b></p>
  <blockquote>
  <xsl:apply-templates/>
  </blockquote>
</xsl:template>


<xsl:key name="actionKey" match="//class" use="@actionType"/>

<!-- Create hyperlink to class or action. If no link text given, default to name of class or action. -->
<xsl:template match="link">
  <xsl:variable name="linktext">
    <xsl:value-of select="."/>
  </xsl:variable>
  <xsl:choose>
    <xsl:when test="@actionType">
      <xsl:for-each select="key('actionKey',string(@actionType))">
        <a href="#{@actionType}={@name}">
          <xsl:choose>
            <xsl:when test="string($linktext)"><xsl:value-of select="$linktext"/></xsl:when>
            <xsl:otherwise>"<xsl:value-of select="@name"/>"</xsl:otherwise>
          </xsl:choose>
        </a>
      </xsl:for-each>
      <!-- testing alternate method <xsl:variable name="actionType" select="@actionType"/>
      <xsl:for-each select="//class[@actionType = $actionType]">
        <a href="#{@actionType}={@name}">
          <xsl:choose>
            <xsl:when test="string($linktext)"><xsl:value-of select="$linktext"/></xsl:when>
            <xsl:otherwise>"<xsl:value-of select="@name"/>"</xsl:otherwise>
          </xsl:choose>
        </a>
      </xsl:for-each>-->
    </xsl:when>
    <xsl:when test="@class">
      <a href="#{@class}">
        <xsl:choose>
          <xsl:when test="string($linktext)"><xsl:value-of select="$linktext"/></xsl:when>
          <xsl:otherwise><xsl:value-of select="@class"/></xsl:otherwise>
        </xsl:choose>
      </a>
    </xsl:when>
  </xsl:choose>
</xsl:template>


<!-- Pass unknown matches through, eg. to allow html in input xml. -->
<xsl:template match="*">
  <xsl:copy>
    <xsl:if test="@*"><xsl:copy-of select="@*"/></xsl:if>
    <xsl:apply-templates/>
  </xsl:copy>
</xsl:template>

</xsl:stylesheet>